#' rPandas: A User-Friendly R Interface to Pandas
#'
#' This package provides a set of wrapper functions that allow R users to
#' interact with Python's pandas library using familiar R syntax.
#'
#' @aliases rPandas
#' @import reticulate
#' @keywords package
"_PACKAGE"
