% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/translate_engine.R
\name{translate_mutate}
\alias{translate_mutate}
\title{Translate R mutate expressions to pandas assign/drop strings}
\usage{
translate_mutate(to_remove = NULL, ...)
}
\arguments{
\item{to_remove}{Character vector of column names to drop.}

\item{...}{Named R expressions.}
}
\value{
A list with components assign_str and drop_str.
}
\description{
Translate R mutate expressions to pandas assign/drop strings
}
\keyword{internal}
