% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/translate_engine.R
\name{translate_filter}
\alias{translate_filter}
\title{Translate an R filter expression into a Python query string}
\usage{
translate_filter(expr)
}
\arguments{
\item{expr}{A bare R expression (e.g., \code{carat > 2 & cut == "Ideal"}).}
}
\value{
A character string of the translated Python query.
}
\description{
Capture a bare R expression and translate it to a Python-compatible string
suitable for use with \code{pandas.DataFrame.query()}.
}
\examples{
translate_filter(carat > 2 & cut == "Ideal")
# -> "(carat > 1) and (cut == 'Ideal')"
}
