% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/translate_engine.R
\name{translate_sort}
\alias{translate_sort}
\title{Translate captured sort expressions into Python .sort_values() arguments}
\usage{
translate_sort(...)
}
\arguments{
\item{...}{Bare column names or \code{desc(colname)} (captured by \code{rlang::enquos}).}
}
\value{
A list with two elements:
\itemize{
\item \verb{$by}: A string for the \code{by} argument (e.g., \code{['cut', 'price']})
\item \verb{$ascending}: A string for the \code{ascending} argument (e.g., \code{[True, False]})
}
}
\description{
Translate captured sort expressions into Python .sort_values() arguments
}
\keyword{internal}
