% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/translate_engine.R
\name{translate_summarize}
\alias{translate_summarize}
\title{Translate named R expressions for .agg()}
\usage{
translate_summarize(...)
}
\arguments{
\item{...}{Named R expressions (e.g., \code{avg_price = mean(price)}).}
}
\value{
A string for the \code{.agg()} method.
}
\description{
Translates R's \code{new = func(old)} syntax into pandas' named aggregation
syntax \verb{new = ('old', 'func')}.
}
\keyword{internal}
