% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/translate_engine.R
\name{translate_calculate}
\alias{translate_calculate}
\title{Translate R function/column names into a pandas agg dictionary}
\usage{
translate_calculate(variable_exprs, function_names)
}
\arguments{
\item{variable_exprs}{A list of enquosured variable names.}

\item{function_names}{A character vector of R function names.}
}
\value{
A string for the \code{.agg()} method (e.g., \code{.agg({'col1': ['mean', 'std']})}).
}
\description{
Translates R's \code{the.variables} and \code{the.functions} into pandas'
dictionary-based \code{.agg()} syntax.
}
\keyword{internal}
